sage_numerical_backends_gurobi: Gurobi backend for Sage MixedIntegerLinearProgram
=================================================================================

Description
-----------

Gurobi backend for Sage MixedIntegerLinearProgram

License
-------

GPLv2+

Upstream Contact
----------------

https://pypi.org/project/passagemath-gurobi/

